[Libreoffice-commits] core.git: Branch 'feature/gsoc14-draw-chained-text-boxes' - svx/source

matteocam matteo.campanelli at gmail.com
Fri Jun 19 19:11:53 PDT 2015


 svx/source/svdraw/svdotextdecomposition.cxx |    6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

New commits:
commit d89a98a71ecd9211fcb494a3524d2f75717ac6f1
Author: matteocam <matteo.campanelli at gmail.com>
Date:   Fri Jun 19 22:11:26 2015 -0400

    Don't set nonOverflowing text to editing outl if in underflow
    
    Change-Id: I471cb8c7e2eedbdf169c45b0fde0ade16b67d1a3

diff --git a/svx/source/svdraw/svdotextdecomposition.cxx b/svx/source/svdraw/svdotextdecomposition.cxx
index 0868bf7..a4de09d 100644
--- a/svx/source/svdraw/svdotextdecomposition.cxx
+++ b/svx/source/svdraw/svdotextdecomposition.cxx
@@ -782,8 +782,10 @@ OutlinerParaObject *SdrTextObj::impGetNonOverflowingParaObject(SdrOutliner *pOut
 void SdrTextObj::impLeaveOnlyNonOverflowingText(SdrOutliner *pOutliner) const
 {
     OutlinerParaObject *pNewText = impGetNonOverflowingParaObject(pOutliner);
-    // we need this when we are in editing mode
-    if (pEdtOutl != NULL)
+
+    bool bInUnderflow =  GetTextChain()->GetLinkHandlingUnderflow(const_cast<SdrTextObj*>(this));
+    // we need this when we are in editing mode (AND this is not an underflow-caused overflow)
+    if (pEdtOutl != NULL && !bInUnderflow)
         pEdtOutl->SetText(*pNewText);
     // adds it to current outliner anyway (useful in static decomposition)
     pOutliner->SetText(*pNewText);


More information about the Libreoffice-commits mailing list